@@ -8,14 +8,10 @@
 # - perl5::i
 
 package perl5::i0;
-use perl5i::0 v2.6.1 ();
 
-1;
+use base 'perl5';
 
-sub import {
-    @_ = ('perl5i::0');
-    goto &perl5i::0::import;
-}
+use constant imports => ( 'perl5i::0' => 'v2.6.1' );
 
 1;
 
